<?php

namespace App\Http\Controllers\Admin;

use App\Services\AdminService;
use App\Services\UserService;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Yajra\DataTables\Facades\DataTables;

class AdminController extends Controller
{
    /**
     * @var UserService
     */
    private $userService;
    /**
     * @var AdminService
     */
    private $adminService;

    public function __construct(UserService $userService,AdminService $adminService){

        $this->userService = $userService;
        $this->adminService = $adminService;
    }

    public function getHome()
    {
        return redirect()->route('get.admin.dashboard');
    }

    public function getMyProfile(){
        return view('admin.my-profile');
    }

    public function getDashboard(){
        $batches=$this->adminService->getBatches();
        $users=$this->userService->getUsers(['role'=>'Customer']);
        $questions=$this->adminService->getQuestions();
        $batch_logins=$this->adminService->getUserBatchLogins(['limit'=>10]);
        $total_batch_logins=$this->adminService->getUserBatchLogins();
        return view('admin.dashboard.index',['batches'=>$batches,'users'=>$users,'questions'=>$questions,'batch_logins'=>$batch_logins,'total_batch_logins'=>$total_batch_logins]);
    }

    public function getBatchList(Request $request){
        $data=$request->all();
        $batches=$this->adminService->getBatches();
        return view('admin.batch.batch-list',['batches'=>$batches]);
    }

    public function getAddBatch($id,Request $request){
        $data=$request->all();
        $batch=null;
        if($id)
            $batch=$this->adminService->getBatches(['id'=>$id],true);
        $questions=$this->adminService->getQuestions(['is_active'=>'Y']);
        return view('admin.iframe.batch.add-batch',['batch'=>$batch,'questions'=>$questions]);
    }

    public function postAddBatch(Request $request){
        $data=$request->all();
        try{
            $this->adminService->saveBatches($data);
            return response()->json(['code'=>200,'msg'=>'Batch Saved Successfully']);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function getSetting(Request $request){
        $data=$request->all();
        $setting=$this->adminService->getTimeSetting();
        return view('admin.setting.time-setting',['setting'=>$setting]);
    }

    public function postSetting(Request $request){
        $data=$request->all();
        try{
            $this->adminService->saveTimeSetting($data);
            return response()->json(['code'=>200,'msg'=>'Setting Saved Successfully']);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function getQuestionOptionList(Request $request){
        $data=$request->all();
        $options=$this->adminService->getQuestionOptions();
        return  view('admin.question.question-option-list',['options'=>$options]);
    }

    public function getAddQuestionOption($id,Request $request){
        $data=$request->all();
        $option=null;
        if($id)
            $option=$this->adminService->getQuestionOptions(['id'=>$id],true);
        $categories=$this->adminService->getQuestionOptionCategories();
        return view('admin.iframe.question.add-question-option',['option'=>$option,'categories'=>$categories]);
    }

    public function postAddQuestionOption(Request $request){
        $data=$request->all();
        try{
            $this->adminService->saveQuestionOptions($data);
            return response()->json(['code'=>200,'msg'=>'Options Saved Successfully']);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function questionOptionCategories(Request $request){
        $data=$request->all();
        $categories=$this->adminService->getQuestionOptionCategories();
        return view('admin.question-option-categories.question-option-categories',['categories'=>$categories]);
    }

    public function addQuestionOptionCategories($id,Request $request){
        $data=$request->all();
        $category=null;
        if($id)
            $category=$this->adminService->getQuestionOptionCategories(['id'=>$id],true);
        return view('admin.iframe.question-option-categories.add-question-option-categories',['category'=>$category]);
    }

    public function postAddQuestionOptionCategories(Request $request){
        $data=$request->all();
        try{
            $this->adminService->saveQuestionOptionCategories($data);
            return response()->json(['code'=>200,'msg'=>'Category Saved Successfully']);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function getQuestionsList(Request $request){
        $data=$request->all();
        $questions=$this->adminService->getQuestions();
        return view('admin.question.question-list',['questions'=>$questions]);
    }

    public function getAddQuestion($id,Request $request){
        $data=$request->all();
        $question=null;
        if($id)
            $question=$this->adminService->getQuestions(['id'=>$id],true);
        $options=$this->adminService->getQuestionOptions();
        return view('admin.iframe.question.add-question',['question'=>$question,'options'=>$options]);
    }

    public function postAddQuestion(Request $request){
        $data=$request->all();
        try{
            $this->adminService->saveQuestions($data);
            return response()->json(['code'=>200,'msg'=>'Question Saved Successfully']);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function getUserBatchLoginList(Request $request){
        $data=$request->all();
        $batch_id=!empty($data['batch_id'])?$data['batch_id']:0;
        $batches=$this->adminService->getBatches();
        $batch_logins=$this->adminService->getUserBatchLogins(['batch_id'=>$batch_id]);
        return view('admin.user-batch.user-batch-login-list',['batch_logins'=>$batch_logins,'batches'=>$batches,'batch_id'=>$batch_id]);
    }

public function getUserBatchLoginListDatatable(Request $request){
    $data=$request->all();
    $items=$this->adminService->getUserBatchLogins(['batch_id'=>$data['batch_id'],'date'=>!empty($data['date'])?date('Y-m-d',strtotime($data['date'])):'','is_batch_finish'=>!empty($data['is_batch_finish'])?$data['is_batch_finish']:'','is_query'=>1]);
    return DataTables::of($items)
        ->addIndexColumn()
        ->addColumn('action', function ($item) {
            $return = '<a href="'.route('get.user.question.answer').'?user_batch_login_id='.$item->id.'" class="btn btn-primary"><i class="fa fa-eye"></i> View</a>';
            return $return;
        })
        ->editColumn('batch_status', function ($item) {
            $return='';
            if($item->is_batch_finish=="Y")
                $return='<span class="badge badge-success">Finished</span>';
            else
                $return='<span class="badge badge-danger">Holding</span>';
            return $return;
        })
        ->editColumn('date', function ($item) {
            return date('d-m-Y',strtotime($item->date));
        })
        ->filter(function ($query) use ($data) {
//                if (!empty($data['invoice_created_by'])) {
//                    $query->where('leads.ga_cost_entered_by', $data['invoice_created_by']);
//                }
        })
        ->rawColumns(['batch_status', 'action'])
        ->make(true);
}

    public function getUsersQuestionAnswers(Request $request){
        $data=$request->all();
        $user_batch_login=$this->adminService->getUserBatchLogins(['id'=>$data['user_batch_login_id']],true);
        $user_questions=$this->adminService->getUsersQuestionAnswer(['user_batch_login_id'=>!empty($data['user_batch_login_id'])?$data['user_batch_login_id']:0]);
        return view('admin.user-batch.user-batch-question-list',['user_questions'=>$user_questions,'user_batch_login'=>$user_batch_login]);
    }

    public function getUserQuestionAnswerEdit($id,Request $request){
        $data=$request->all();
        $question=$this->adminService->getUsersQuestionAnswer(['id'=>$id],true);
        $options=$this->adminService->getQuestionOptions();
        return view('admin.iframe.question.user-question-answer-edit',['question'=>$question,'options'=>$options]);
    }

    public function postUserQuestionAnswerEdit(Request $request){
        $data=$request->all();
        try{
            $option_ids=null;$option_answer=null;$is_auto_answer='N';
            if(!empty($data['option_ids'])){
                $option_answers=$this->adminService->getQuestionOptions(['ids'=>$data['option_ids']]);
                $option_answer=collect($option_answers)->pluck('option_name')->toArray();
                $option_answer=implode(',',$option_answer);
                $option_ids=collect($option_answers)->pluck('id')->toArray();
                $option_ids=implode(',',$option_ids);
            }
            $this->adminService->saveUserQuestionAnswer(['id'=>$data['id'],'option_answer'=>$option_answer,'option_ids'=>$option_ids,'is_edit_admin'=>$data['is_edit_admin'],'is_auto_answer'=>$is_auto_answer]);
            return response()->json(['code'=>200,'msg'=>'Question Answer Edit Successfully']);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }

    }

    public function getExportBatch(Request $request){
        $data=$request->all();
        $batches=$this->adminService->getBatches();
        return view('admin.export-batch.export-batch',['batches'=>$batches]);
    }
}
