<?php

namespace App\Http\Controllers\Admin;

use App\Services\AdminService;
use App\Services\UserService;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class AdminController extends Controller
{
    /**
     * @var UserService
     */
    private $userService;
    /**
     * @var AdminService
     */
    private $adminService;

    public function __construct(UserService $userService,AdminService $adminService){

        $this->userService = $userService;
        $this->adminService = $adminService;
    }

    public function getHome()
    {
        return redirect()->route('get.admin.dashboard');
    }

    public function getMyProfile(){
        return view('admin.my-profile');
    }

    public function getDashboard(){
        return view('admin.dashboard.index');
    }

    public function getLanguageList(Request $request){
        $data=$request->all();
        $languages=$this->adminService->getLanguages();
        return view('admin.language.language-list',['languages'=>$languages]);
    }

    public function getAddLanguage($id=0,Request $request){
        $data=$request->all();
        $language=null;
        if($id)
            $language=$this->adminService->getLanguages(['id'=>$id],true);
        return view('admin.iframe.language.add-language',['language'=>$language]);
    }

    public function postAddLanguage(Request $request){
        $data=$request->all();
        try{
            $this->adminService->saveLanguages($data);
            return response()->json(['code'=>200,'msg'=>'Saved Successfully']);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function getCategoriesList(Request $request){
        $data=$request->all();
        $languages=$this->adminService->getLanguages();
        $lan_id=!empty($data['lan_id'])?$data['lan_id']:$languages[0]->id;
        $language=$this->adminService->getLanguages(['id'=>$lan_id],true);
        $categories=$this->adminService->getCategories(['language_id'=>$lan_id]);
        return view('admin.category.category-list',['categories'=>$categories,'languages'=>$languages,'language'=>$language,'lan_id'=>$lan_id]);
    }

    public function getAddCategory($id=0,Request $request){
        $data=$request->all();
        $lan_id=!empty($data['lan_id'])?$data['lan_id']:null;
        $languages=$this->adminService->getLanguages();
        $category=null;
        if($id){
            $category=$this->adminService->getCategories(['id'=>$id],true);
        }
        return view('admin.iframe.category.add-category',['category'=>$category,'languages'=>$languages,'lan_id'=>$lan_id]);
    }

    public function postAddCategory(Request $request){
        $data=$request->all();
        try{
            if($request->hasFile('icon_image')){
                $data['icon_image']=$this->adminService->uploadFile($request->file('icon_image'));
            }
            if($request->hasFile('banner_image')){
                $data['banner_image']=$this->adminService->uploadFile($request->file('banner_image'));
            }
            $this->adminService->saveCategories($data);
            return response()->json(['code'=>200,'msg'=>'Saved Successfully']);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function getItemsList($category_id,Request $request){
        $data=$request->all();
        $category=$this->adminService->getCategories(['id'=>$category_id],true);
        $items=$this->adminService->getItems(['category_id'=>$category_id]);
        return view('admin.items.items-list',['category_id'=>$category_id,'category'=>$category,'items'=>$items]);
    }

    public function getAddItems($id=0,Request $request){
        $data=$request->all();
        $category_id=!empty($data['category_id'])?$data['category_id']:null;
        $item=null;$category=null;
        if($id)
            $item=$this->adminService->getItems(['id'=>$id],true);
        if($category_id)
            $category=$this->adminService->getCategories(['id'=>$category_id],true);
        return view('admin.iframe.items.add-items',['item'=>$item,'category'=>$category,'category_id'=>$category_id]);
    }

    public function postAddItem(Request $request){
        $data=$request->all();
        try{
            if($request->hasFile('audio_url')){
                $data['audio_url']=$this->adminService->uploadFile($request->file('audio_url'));
            }
            if($request->hasFile('image')){
                $data['image']=$this->adminService->uploadFile($request->file('image'));
            }
            $this->adminService->saveItems($data);
            return response()->json(['code'=>200,'msg'=>'Saved Successfully']);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

}
