<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Services\AdminService;
use Illuminate\Encryption\Encrypter;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Crypt;

class ApiController extends Controller
{
    private $adminService;

    public function __construct(AdminService $adminService){
        $this->adminService=$adminService;
    }
    public function getSetting(Request $request){
        $data=$request->all();
        try{
            $time_setting=$this->adminService->getTimeSetting();
            return response()->json(['code'=>200,'msg'=>'','json'=>['time_setting'=>$time_setting]]);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function getBatchList(Request $request){
        $data=$request->all();
        try{
            $batches=$this->adminService->getBatches(['is_active'=>'Y']);
            return response()->json(['code'=>200,'msg'=>'','json'=>['batches'=>$batches]]);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function getOptions(Request $request){
        $data=$request->all();
        try{
            $categories=$this->adminService->getQuestionOptionCategories();
            $temp_categories=[];
            foreach($categories as$key=>$category){
                $options=$this->adminService->getQuestionOptions(['category_id'=>$category->id]);
                if(count($options)>0){
                    $category->options=$options;
                    $temp_categories[]=$category;
                }
            }
            $categories=$temp_categories;
            echo "<pre>";print_r($categories);exit;
            $options=$this->adminService->getQuestionOptions();
            return response()->json(['code'=>200,'msg'=>'','json'=>['options'=>$options]]);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function getQuestions(Request $request){
        $data=$request->all();
        try{
            $not_question_ids=[];
            $batch_login=$this->adminService->getUserBatchLogins(['id'=>$data['user_batch_login_id']],true);
            if(!empty($data['user_batch_login_id'])){
                $question_ids=$this->adminService->getUsersQuestionAnswer(['user_batch_login_id'=>$data['user_batch_login_id']]);
                $not_question_ids=collect($question_ids)->pluck('question_id')->toArray();
            }
            $questions=$this->adminService->getQuestions(['is_active'=>'Y','not_question_ids'=>$not_question_ids,'from_id'=>$batch_login->from_question_id,'to_id'=>$batch_login->to_question_id]);
            return response()->json(['code'=>200,'msg'=>'','json'=>['questions'=>$questions]]);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function getUserHoldBatch(Request $request){
        $data=$request->all();
        try{
            $hold_user_batch=$this->adminService->getUserBatchLogins(['user_id'=>$data['user_id'],'is_batch_finish'=>'N']);
            return response()->json(['code'=>200,'msg'=>'','json'=>['hold_user_batch'=>$hold_user_batch]]);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function saveUserBatchFinish(Request $request){
        $data=$request->all();
        try{
            $user_batch=$this->adminService->saveUserBatchLogin(['user_batch_login_id'=>$data['user_batch_login_id'],'is_batch_finish'=>$data['is_batch_finish']]);
            return response()->json(['code'=>200,'msg'=>'Batch Saved Successfully','json'=>['user_batch'=>$user_batch]]);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function saveUserBatch(Request $request){
        $data=$request->all();
        try{
            $user_batch=$this->adminService->saveUserBatchLogin(['user_id'=>$data['user_id'],'batch_id'=>$data['batch_id'],'date'=>date('Y-m-d')]);
            return response()->json(['code'=>200,'msg'=>'Batch Saved Successfully','json'=>['user_batch'=>$user_batch]]);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }

    public function saveUserQuestionAnswer(Request $request){
        $data=$request->all();
        try{
            if(!empty($data['option_ids']))
                $data['option_ids']=implode(',',$data['option_ids']);
            if(!empty($data['option_answer']))
                $data['option_answer']=implode(',',$data['option_answer']);
            if(empty($data['option_answer']) && empty($data['option_ids'])){
                $data['is_auto_answer']='Y';
            }
            $this->adminService->saveUserQuestionAnswer(['user_id'=>$data['user_id'],'user_batch_login_id'=>$data['user_batch_login_id'],'question_id'=>$data['question_id'],'option_ids'=>!empty($data['option_ids'])?$data['option_ids']:null,'option_answer'=>!empty($data['option_answer'])?$data['option_answer']:null,'is_auto_answer'=>!empty($data['is_auto_answer'])?$data['is_auto_answer']:'N']);
            return response()->json(['code'=>200,'msg'=>'Answer Saved Successfully','json'=>[]]);
        }catch (\Exception $e){
            return response()->json(['code'=>300,'msg'=>$e->getMessage()]);
        }
    }
}
