<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Services\UserService;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Http\Request;
use Illuminate\Contracts\Auth\Guard;

class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your dashboard screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login.
     *
     * @var string
     */
    protected $redirectTo = '/dashboard';
    /**
     * @var Guard
     */
    private $guard;
    /**
     * @var UserService
     */
    private $userService;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(Guard $guard,UserService $userService)
    {
        $this->middleware('guest')->except('logout');
        $this->guard = $guard;
        $this->userService = $userService;
    }

    public function getLogin()
    {
        return view('auth.login');
    }

    public function postLogin(Request $request)
    {
        $data=$request->all();
        if ($this->guard->attempt(['email'=>$data['email'],'password'=>$data['password']])){
            return response()->json(['code'=>200,'msg'=>'','redirect'=>route('get.admin.dashboard')]);
        }else{
            return response()->json(['code'=>300,'msg'=>'Email and Password are wrong']);
        }
    }

    public function logout()
    {
        \Session::flush();
        $this->guard->logout();
        \Auth::logout();
        return redirect("/");
    }
}
