@extends('admin.iframe.iframe-layout')
@section('title','Add Batch')
@section('page-css')
    <link rel="stylesheet" type="text/css" href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" />
@stop
@section('content')
    <div class="card card-default">
        <form action="{{route('post.add.batch')}}" method="post" id="form" enctype="multipart/form-data">
            <input type="hidden" name="_token" value="{{csrf_token()}}">
            <input type="hidden" name="batch_id" value="{{!empty($batch)?$batch->id:0}}">
            <div class="card-header">
                <h4>{{!empty($batch)?'Edit':'Add'}} Batch</h4>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-sm-12">
                        <div class="form-group">
                            <label>Batch name</label>
                            <input class="form-control" type="text" name="name" value="{{!empty($batch)?$batch->name:''}}">
                        </div>
                    </div>
                    <div class="col-sm-12">
                        <div class="form-group">
                            <label>Status</label>
                            <select name="is_active" id="is_active" class="form-control">
                                <option value="Y" @if(!empty($batch) && $batch->is_active=='Y') selected @endif>Active</option>
                                <option value="N" @if(!empty($batch) && $batch->is_active=='N') selected @endif>De Active</option>
                            </select>
                        </div>
                    </div>
                    <div class="col-sm-12">
                        <div class="form-group">
                            <label>From Question</label>
                            <select name="from_question_id" id="from_question_id" class="form-control">
                                @foreach($questions as $question)
                                    <option value="{{$question->id}}" @if(!empty($batch) && $batch->from_question_id==$question->id) selected @endif>{{$question->question}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                    <div class="col-sm-12">
                        <div class="form-group">
                            <label>To Question</label>
                            <select name="to_question_id" id="to_question_id" class="form-control">
                                @foreach($questions as $question)
                                    <option value="{{$question->id}}" @if(!empty($batch) && $batch->to_question_id==$question->id) selected @endif>{{$question->question}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                </div>
            </div>
            <div class="card-footer text-center">
                <button type="submit" class="btn btn-success">Submit</button>
            </div>
        </form>
    </div>
@stop
@section('page-js')
    <script type="text/javascript" src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
    <script>
        $(document).ready(function (){
            setTimeout(function (){
                $('#from_question_id').select2();
                $('#to_question_id').select2();
                resize_colorbox();
            });
            $('#form').validate({
                lang: 'it',
                errorClass: 'error error_preview',
                highlight: function (element, errorClass, validClass) {
                },
                rules: {
                    batch_name: {
                        required: true,
                    },
                },
                submitHandler: function (form) {
                    if(!checkFormValidation()) return;
                    formHandler($(form), function () {
                        $('#ajax_loader').show();
                    },
                    function (data) {
                        if (data.code===300){
                            $("#ajax_loader").hide();
                            Swal.fire("Oops", data.msg, "error")
                        }
                        else if(data.code===200){
                            if (data.redirect && data.redirect!==""){
                                window.location.href=data.redirect;
                            }
                            else{
                                parent.window.location.href=parent.window.location.href;
                            }
                        }
                    })
                }
            });
        });

        function checkFormValidation(){
            if(Number($('#from_question_id').val())>Number($('#to_question_id').val())){
                Swal.fire("Oops",'Please Select Proper Question Range', "error")
                return false;
            }
            return true;
        }
    </script>
@stop
